@@ -27,7 +27,7 @@
 #'          or saved using ggsave function.
 #'
 #'
-#' @references{\url{https://local.disia.unifi.it/stefanini/RESEARCH/coneu/tutorial-conv.html}}
+#' @references{\url{https://unimi2013-my.sharepoint.com/:u:/g/personal/federico_stefanini_unimi_it/EW0cVSIgbtZAvLPNbqcxdX8Bfn5VGSRHfAH88hQwc_RIEQ?e=MgtSZu}}
 #'
 #'
 #' @examples
@@ -179,7 +179,7 @@ graph_departure <- function( myTB,
       ggplot2::scale_x_continuous(breaks = breaks_x,
                          labels = breaks_x) +
       ggplot2::xlab(axis_name_x) +
-      ggplot2::guides(fill = FALSE) +
+      ggplot2::guides(fill = "none") +
       # ggplot2::geom_text(data=myTB2,
       #                    ggplot2::aes(x = myTB2$`time`,
       #                                 y = myTB2$`position`,
